@@ -1,5 +1,6 @@
 import collections
 import inspect
+import os
 import socket
 import sys
 import tempfile
@@ -10,7 +11,7 @@ from itertools import islice
 from pathlib import Path
 from unittest import mock
 
-from bpython import config, repl, cli, autocomplete
+from bpython import config, repl, autocomplete
 from bpython.line import LinePart
 from bpython.test import (
     MagicIterMock,
@@ -59,7 +60,7 @@ class FakeRepl(repl.Repl):
         raise NotImplementedError
 
     def reprint_line(
-        self, lineno: int, tokens: List[Tuple[repl._TokenType, str]]
+        self, lineno: int, tokens: list[tuple[repl._TokenType, str]]
     ) -> None:
         raise NotImplementedError
 
@@ -67,13 +68,6 @@ class FakeRepl(repl.Repl):
         raise NotImplementedError
 
 
-class FakeCliRepl(cli.CLIRepl, FakeRepl):
-    def __init__(self):
-        self.s = ""
-        self.cpos = 0
-        self.rl_history = FakeHistory()
-
-
 class TestMatchesIterator(unittest.TestCase):
     def setUp(self):
         self.matches = ["bobby", "bobbies", "bobberina"]
@@ -183,7 +177,7 @@ class TestArgspec(unittest.TestCase):
         self.repl.cursor_offset = len(line)
 
     def test_func_name(self):
-        for (line, expected_name) in [
+        for line, expected_name in [
             ("spam(", "spam"),
             # map pydoc has no signature in pypy
             ("spam(any([]", "any") if pypy else ("spam(map([]", "map"),
@@ -194,7 +188,7 @@ class TestArgspec(unittest.TestCase):
             self.assertEqual(self.repl.current_func.__name__, expected_name)
 
     def test_func_name_method_issue_479(self):
-        for (line, expected_name) in [
+        for line, expected_name in [
             ("o.spam(", "spam"),
             # map pydoc has no signature in pypy
             ("o.spam(any([]", "any") if pypy else ("o.spam(map([]", "map"),
@@ -313,7 +307,7 @@ class TestGetSource(unittest.TestCase):
         try:
             self.repl.get_source_of_current_name()
         except repl.SourceNotFound as e:
-            self.assertEqual(e.args[0], msg)
+            self.assertEqual(msg, e.args[0])
         else:
             self.fail("Should have raised SourceNotFound")
 
@@ -338,9 +332,14 @@ class TestGetSource(unittest.TestCase):
         self.assert_get_source_error_for_current_function(
             collections.defaultdict.copy, "No source code found for INPUTLINE"
         )
-        self.assert_get_source_error_for_current_function(
-            collections.defaultdict, "could not find class definition"
-        )
+        if sys.version_info[:2] >= (3, 13):
+            self.assert_get_source_error_for_current_function(
+                collections.defaultdict, "source code not available"
+            )
+        else:
+            self.assert_get_source_error_for_current_function(
+                collections.defaultdict, "could not find class definition"
+            )
 
     def test_current_line(self):
         self.repl.interp.locals["a"] = socket.socket
@@ -530,156 +529,19 @@ class TestRepl(unittest.TestCase):
                 inspect.Parameter("pinetree", inspect.Parameter.KEYWORD_ONLY),
             ])
         """
-        for line in code.split("\n"):
-            print(line[8:])
-            self.repl.push(line[8:])
+        code = [x[8:] for x in code.split("\n")]
+        for line in code:
+            self.repl.push(line)
 
-        self.assertTrue(self.repl.complete())
-        self.assertTrue(hasattr(self.repl.matches_iter, "matches"))
-        self.assertEqual(self.repl.matches_iter.matches, ["apple2=", "apple="])
-
-
-class TestCliRepl(unittest.TestCase):
-    def setUp(self):
-        self.repl = FakeCliRepl()
-
-    def test_atbol(self):
-        self.assertTrue(self.repl.atbol())
-
-        self.repl.s = "\t\t"
-        self.assertTrue(self.repl.atbol())
-
-        self.repl.s = "\t\tnot an empty line"
-        self.assertFalse(self.repl.atbol())
-
-    def test_addstr(self):
-        self.repl.complete = mock.Mock(True)
-
-        self.repl.s = "foo"
-        self.repl.addstr("bar")
-        self.assertEqual(self.repl.s, "foobar")
-
-        self.repl.cpos = 3
-        self.repl.addstr("buzz")
-        self.assertEqual(self.repl.s, "foobuzzbar")
-
-
-class TestCliReplTab(unittest.TestCase):
-    def setUp(self):
-        self.repl = FakeCliRepl()
-
-    # 3 Types of tab complete
-    def test_simple_tab_complete(self):
-        self.repl.matches_iter = MagicIterMock()
-        self.repl.matches_iter.__bool__.return_value = False
-        self.repl.complete = mock.Mock()
-        self.repl.print_line = mock.Mock()
-        self.repl.matches_iter.is_cseq.return_value = False
-        self.repl.show_list = mock.Mock()
-        self.repl.funcprops = mock.Mock()
-        self.repl.arg_pos = mock.Mock()
-        self.repl.matches_iter.cur_line.return_value = (None, "foobar")
-
-        self.repl.s = "foo"
-        self.repl.tab()
-        self.assertTrue(self.repl.complete.called)
-        self.repl.complete.assert_called_with(tab=True)
-        self.assertEqual(self.repl.s, "foobar")
-
-    @unittest.skip("disabled while non-simple completion is disabled")
-    def test_substring_tab_complete(self):
-        self.repl.s = "bar"
-        self.repl.config.autocomplete_mode = (
-            autocomplete.AutocompleteModes.FUZZY
-        )
-        self.repl.tab()
-        self.assertEqual(self.repl.s, "foobar")
-        self.repl.tab()
-        self.assertEqual(self.repl.s, "foofoobar")
-
-    @unittest.skip("disabled while non-simple completion is disabled")
-    def test_fuzzy_tab_complete(self):
-        self.repl.s = "br"
-        self.repl.config.autocomplete_mode = (
-            autocomplete.AutocompleteModes.FUZZY
-        )
-        self.repl.tab()
-        self.assertEqual(self.repl.s, "foobar")
-
-    # Edge Cases
-    def test_normal_tab(self):
-        """make sure pressing the tab key will
-        still in some cases add a tab"""
-        self.repl.s = ""
-        self.repl.config = mock.Mock()
-        self.repl.config.tab_length = 4
-        self.repl.complete = mock.Mock()
-        self.repl.print_line = mock.Mock()
-        self.repl.tab()
-        self.assertEqual(self.repl.s, "    ")
-
-    def test_back_parameter(self):
-        self.repl.matches_iter = mock.Mock()
-        self.repl.matches_iter.matches = True
-        self.repl.matches_iter.previous.return_value = "previtem"
-        self.repl.matches_iter.is_cseq.return_value = False
-        self.repl.show_list = mock.Mock()
-        self.repl.funcprops = mock.Mock()
-        self.repl.arg_pos = mock.Mock()
-        self.repl.matches_iter.cur_line.return_value = (None, "previtem")
-        self.repl.print_line = mock.Mock()
-        self.repl.s = "foo"
-        self.repl.cpos = 0
-        self.repl.tab(back=True)
-        self.assertTrue(self.repl.matches_iter.previous.called)
-        self.assertTrue(self.repl.s, "previtem")
-
-    # Attribute Tests
-    @unittest.skip("disabled while non-simple completion is disabled")
-    def test_fuzzy_attribute_tab_complete(self):
-        """Test fuzzy attribute with no text"""
-        self.repl.s = "Foo."
-        self.repl.config.autocomplete_mode = (
-            autocomplete.AutocompleteModes.FUZZY
-        )
-
-        self.repl.tab()
-        self.assertEqual(self.repl.s, "Foo.foobar")
-
-    @unittest.skip("disabled while non-simple completion is disabled")
-    def test_fuzzy_attribute_tab_complete2(self):
-        """Test fuzzy attribute with some text"""
-        self.repl.s = "Foo.br"
-        self.repl.config.autocomplete_mode = (
-            autocomplete.AutocompleteModes.FUZZY
-        )
-
-        self.repl.tab()
-        self.assertEqual(self.repl.s, "Foo.foobar")
-
-    # Expand Tests
-    def test_simple_expand(self):
-        self.repl.s = "f"
-        self.cpos = 0
-        self.repl.matches_iter = mock.Mock()
-        self.repl.matches_iter.is_cseq.return_value = True
-        self.repl.matches_iter.substitute_cseq.return_value = (3, "foo")
-        self.repl.print_line = mock.Mock()
-        self.repl.tab()
-        self.assertEqual(self.repl.s, "foo")
-
-    @unittest.skip("disabled while non-simple completion is disabled")
-    def test_substring_expand_forward(self):
-        self.repl.config.autocomplete_mode = (
-            autocomplete.AutocompleteModes.SUBSTRING
-        )
-        self.repl.s = "ba"
-        self.repl.tab()
-        self.assertEqual(self.repl.s, "bar")
-
-    @unittest.skip("disabled while non-simple completion is disabled")
-    def test_fuzzy_expand(self):
-        pass
+        with mock.patch(
+            "bpython.inspection.inspect.getsourcelines",
+            return_value=(code, None),
+        ):
+            self.assertTrue(self.repl.complete())
+            self.assertTrue(hasattr(self.repl.matches_iter, "matches"))
+            self.assertEqual(
+                self.repl.matches_iter.matches, ["apple2=", "apple="]
+            )
 
 
 if __name__ == "__main__":
